@@ -12,6 +12,7 @@
 #'        plot   = TRUE,
 #'        paths  = NULL,
 #'        exogenous        = NULL, 
+#'        outcome          = NULL, 
 #'        conv_vars        = NULL,
 #'        conv_length      = 16, 
 #'        conv_interval    = 1,
@@ -41,7 +42,9 @@
 #' negative weights.
 #' @param paths lavaan-style syntax containing paths with which to begin model
 #' estimation. That is, Y~X indicates that Y is regressed on X, or X 
-#' predicts Y. If no header is used, then variables should be referred to with 
+#' predicts Y. Paths can also be set to a specific value for estimation using \code{lavaan}-style syntax 
+#' (e.g., 'V4 ~ 0.5*V3'), or set to 0 so that they will not be estimated 
+#' (e.g., 'V4 ~ 0*V3'). If no header is used, then variables should be referred to with 
 #' V followed (with no separation) by the column number. If a header is used, 
 #' variables should be referred to using variable names. To reference lag 
 #' variables, "lag" should be added to the end of the variable name with no 
@@ -51,11 +54,15 @@
 #' If no header is used, then variables should be referred to with V followed 
 #' (with no separation) by the column number. If a header is used, variables 
 #' should be referred to using variable names.  Defaults to NULL.
+#' @param outcome Vector of variable names to be treated as outcome (optional). This is a variable
+#' that can be predicted by others but cannot predict. If no header is used, then variables should be referred to with V followed
+#' (with no separation) by the column number.  If a header is used, variables should be referred 
+#' to using variable names.
 #' @param conv_vars Vector of variable names to be convolved via smoothed Finite Impulse 
 #' Response (sFIR). Defaults to NULL.
 #' @param conv_length Expected response length in seconds. For functional MRI BOLD, 16 seconds (default) is typical
 #' for the hemodynamic response function. 
-#' @param conv_interval Interval between data acquisition. Currently must be a constant. For 
+#' @param conv_interval Interval between data acquisition. Currently conv_length/conv_interval must be a constant. For 
 #' fMRI studies, this is the repetition time. Defaults to 1. 
 #' @param mult_vars Vector of variable names to be multiplied to explore bilinear/modulatory
 #' effects (optional). All multiplied variables will be treated as exogenous (X can predict
@@ -97,6 +104,9 @@
 #'  path for each individual.
 #'  \item{\strong{\emph{id}StdErrors}} Contains individual-level standard errors 
 #'  for each path for each individual.
+#'  \item{\strong{\emph{id}EstRF}} Produced if conv_vars is not NULL. 
+#'  Contains individual-level estimated response function (e.g., hemodynamic response function (HRF) or relevant response function).
+#'  One column for each convolved variable, output length is equal to conv_length input.
 #'  \item{\strong{\emph{id}Plot}} Contains individual-level plots. Red paths 
 #'  represent positive weights and blue paths represent negative weights.
 #' }
@@ -121,6 +131,7 @@ indSEM <- function(data   = NULL,
                    plot   = TRUE,
                    paths  = NULL,
                    exogenous = NULL, 
+                   outcome   = NULL, 
                    conv_vars      = NULL,
                    conv_length    = 16, 
                    conv_interval = 1, 
@@ -197,7 +208,9 @@ indSEM <- function(data   = NULL,
               vcov            = store$vcov,
               vcovfull        = store$vcovfull,
               psi             = store$psi,
-              psi_unstd       = store$psiunstd)
+              psi_unstd       = store$psiunstd,
+              rf_est         = dat$rf_est # 7.02.22 kad: added HRF estimates 
+              )
   
   class(res) <-  "indSEMp"
   
